#### POLINATION AND REPRODUCTION ###

setwd("~/Dropbox/villav_colm/datos/")
#setwd("C:\\Users\\Maria\\Dropbox\\villav_colm\\datos")

#LIBRARIES
library("dplyr")
library("ggplot2")
library("glmmTMB")
library("lme4")
library("broom.mixed")
library("performance")
library("multcomp")
library("sjPlot")
library("DHARMa")
library("effects")
library("ggplot2")
library("ggeffects")
library("gridExtra")
library("grid")
library("ggpubr")
library("nlme")

#DATA

#2017
pol.dat.ld.2017 <- read.table(file = "villav_colm_pol_2017_mod.csv", sep=";", header=T, na.strings = "NA")
frsem.dat.ld.2017 <- read.table(file = "villav_colm_reprod_2017.csv", sep = ";", header = T, na.strings = "NA")

#2018
pol.dat.2018 <- read.table(file = "villav_colm_pol_2018.csv", sep=";", header=T, na.strings = "NA")
frsem.dat.2018 <- read.table(file = "villav_colm_reprod_2018.csv", sep = ";", header = T, na.strings = "NA")

#2019
pol.dat.2019 <- read.table(file = "villav_colm_pol_2019.csv", sep=";", header=T, na.strings = "NA")
frsem.dat.2019 <- read.table(file = "villav_colm_reprod_2019.csv", sep = ";", header = T, na.strings = "NA")

#DATA TRANSFORMATION
#join years
pol.dat <- bind_rows(pol.dat.ld.2017, pol.dat.2018, pol.dat.2019)
pol.dat<- pol.dat %>% transform(year=as.factor(year), sitio=as.factor(sitio), distancia.m=as.factor(distancia.m), no.planta=as.factor(no.planta)) 

frsem.dat <- bind_rows(frsem.dat.ld.2017, frsem.dat.2018, frsem.dat.2019)
frsem.dat <- frsem.dat %>% transform(year=as.factor(year), sitio=as.factor(sitio), distancia.m=as.factor(distancia.m), no.planta=as.factor(no.planta))

#Larrea divaricata

pol.ld <- pol.dat %>% filter(especie=="lar.div") %>% 
  rename(pol.con=no.pol.con, pol.het=no.pol.het, flor=no.flor, tubes.c=no.tubos.cerca, tubes.l=no.tubos.lejos) %>%
  mutate(pol.tot=pol.con+pol.het, tubes.ratio=tubes.l/tubes.c) %>% 
  mutate(pol.con.ratio=pol.con/pol.tot) 

fruit.set.ld <-frsem.dat %>% filter(especie=="lar.div") %>%
  rename(planta=no.planta, pimp = no.pimp.1, flor.1=no.flor.1, fruto.1=no.fruto.1, flor.2=no.flor.2, fruto.2=no.fruto.2, semilla = no.semillas) %>%
  dplyr::select(-fruto, -semilla, -viabilidad, -peso) %>%
  group_by(year, sitio, distancia.m, planta) %>%
  distinct(planta, .keep_all = TRUE) %>%
  mutate(fruit.set=((fruto.2)/(pimp+flor.1+flor.2)))

seed.set.ld <- frsem.dat %>% filter(especie=="lar.div") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2, -viabilidad, -no.fruto.1, -no.fruto.2, -peso) %>%
  group_by(year, sitio, distancia.m, planta, fruto) %>%
  summarise(seed.set=max(semilla)) 

viab.ld <- frsem.dat %>% filter(especie=="lar.div") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2,  -no.fruto.1, -no.fruto.2) 


#zuccagnia punctata

pol.zp <- pol.dat %>% filter(especie=="zuc.pun") %>% 
  rename(pol.con=no.pol.con, pol.het=no.pol.het, flor=no.flor, tubes.c=no.tubos.cerca, tubes.l=no.tubos.lejos) %>%
  mutate(pol.tot=pol.con+pol.het, tubes.ratio=tubes.l/tubes.c) %>% 
  mutate(pol.con.ratio=pol.con/pol.tot) 

fruit.set.zp <-frsem.dat %>% filter(especie=="zuc.pun") %>%
  rename(planta=no.planta, pimp = no.pimp.1, flor.1=no.flor.1, fruto.1=no.fruto.1, flor.2=no.flor.2, fruto.2=no.fruto.2, semilla = no.semillas) %>%
  dplyr::select(-fruto, -semilla, -viabilidad, -peso) %>%
  group_by(year, sitio, distancia.m, planta) %>%
  distinct(planta, .keep_all = TRUE) %>%
  mutate(fruit.set=((fruto.2)/(pimp+flor.1+flor.2)))

seed.set.zp <- frsem.dat %>%  filter(especie=="zuc.pun") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2, -viabilidad, -no.fruto.1, -no.fruto.2) %>%
  group_by(year, sitio, distancia.m, planta) %>%
  summarise(seed.set=(max(semilla)/max(fruto)))

viab.zp <- frsem.dat %>% filter(especie=="zuc.pun") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2,  -no.fruto.1, -no.fruto.2) 

#Larrea cuneifolia

pol.lc <- pol.dat %>% filter(especie=="lar.cun") %>% 
  rename(pol.con=no.pol.con, pol.het=no.pol.het, flor=no.flor, tubes.c=no.tubos.cerca, tubes.l=no.tubos.lejos) %>%
  mutate(pol.tot=pol.con+pol.het, tubes.ratio=tubes.l/tubes.c) %>% 
  mutate(pol.con.ratio=pol.con/pol.tot) 

fruit.set.lc <-frsem.dat %>% filter(especie=="lar.cun") %>%
  rename(planta=no.planta, pimp = no.pimp.1, flor.1=no.flor.1, fruto.1=no.fruto.1, flor.2=no.flor.2, fruto.2=no.fruto.2, semilla = no.semillas) %>%
  dplyr::select(-fruto, -semilla, -viabilidad, -peso) %>%
  group_by(year, sitio, distancia.m, planta) %>%
  distinct(planta, .keep_all = TRUE) %>%
  mutate(fruit.set=((fruto.2)/(pimp+flor.1+flor.2)))

seed.set.lc <- frsem.dat %>% filter(especie=="lar.cun") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2, -viabilidad, -no.fruto.1, -no.fruto.2, -peso) %>%
  group_by(year, sitio, distancia.m, planta, fruto) %>%
  summarise(seed.set=max(semilla)) 

viab.lc <- frsem.dat %>% filter(especie=="lar.cun") %>%
  rename(planta =no.planta, semilla=no.semillas) %>%
  dplyr::select(-no.pimp.1, -no.flor.1, -no.flor.2,  -no.fruto.1, -no.fruto.2) 


#DATA ANALYSIS

#### larrea divaricata

##Conspecific pollen grains#

#formulas

f1 <- pol.con ~ distancia.m*year + (1|sitio/no.planta)
f2 <- pol.con ~ distancia.m + year + (1|sitio/no.planta)

#GLMM

m1 <- glmmTMB(f1, data = pol.ld, family = "gaussian")
m2 <- glmmTMB(f2, data = pol.ld, family = "gaussian")

m3 <- glmmTMB(f1, data = pol.ld, family = "poisson")
m4 <- glmmTMB(f2, data = pol.ld, family = "poisson")

m5 <- glmmTMB(f1, data = pol.ld, family = "nbinom1")
m6 <- glmmTMB(f2, data = pol.ld, family = "nbinom1")


AIC(m1,m2,m3,m4,m5,m6) #m6
AIC(m1,m4,m2,m5,m3,m6)

simulationOutput <- simulateResiduals(fittedModel = m6, plot = F)
plot(simulationOutput)

summary(m6)


##Heteroespecific pollen grains

#formulas

f3 <- formula(pol.het ~ distancia.m*year + (1|sitio/no.planta))
f4 <- formula(pol.het ~ distancia.m + year + (1|sitio/no.planta))


#GLMM

m7 <- glmmTMB(f3, data = pol.ld, family = "gaussian")
m8 <- glmmTMB(f4, data = pol.ld, family = "gaussian")

m9 <- glmmTMB(f3, data = pol.ld, family = "poisson")
m10 <- glmmTMB(f4, data = pol.ld, family = "poisson")

m11 <- glmmTMB(f3, data = pol.ld, family = "nbinom1")
m12 <- glmmTMB(f4, data = pol.ld, family = "nbinom1")

AIC(m7,m8,m9,m10,m11,m12) #m12
AIC(m7,m10,m8,m11,m9,m12)

simulationOutput <- simulateResiduals(fittedModel = m12, plot = F)
plot(simulationOutput)

summary(m12)

##Total pollen grains

#formulas

f5 <- formula(pol.tot ~ distancia.m*year + (1|sitio/no.planta))
f6 <- formula(pol.tot ~ distancia.m + year + (1|sitio/no.planta))


#GLMM

m13 <- glmmTMB(f5, data = pol.ld, family = "gaussian")
m14 <- glmmTMB(f6, data = pol.ld, family = "gaussian")

m15 <- glmmTMB(f5, data = pol.ld, family = "poisson")
m16 <- glmmTMB(f6, data = pol.ld, family = "poisson")

m17 <- glmmTMB(f5, data = pol.ld, family = "nbinom1")
m18 <- glmmTMB(f6, data = pol.ld, family = "nbinom1")

AIC(m13,m14,m15,m16,m17,m18) #m18
AIC(m13,m16,m14,m17,m15,m18)

simulationOutput <- simulateResiduals(fittedModel = m18, plot = F)
plot(simulationOutput)

summary(m18)


##conspecific pollen grain ratio

#formulas

f7 <- formula(pol.con.ratio ~ distancia.m*year + (1|sitio/no.planta))
f8 <- formula(pol.con.ratio ~ distancia.m + year + (1|sitio/no.planta))

#GLMM
m19 <- glmmTMB(f7, data = pol.ld, family = "binomial")
m20 <- glmmTMB(f8, data = pol.ld, family = "binomial")

#Beta distribution -> (0,1). So pol.con.ratio -> (0.0001,0.9999)
pol.ld.m2 <- as.data.frame(pol.ld) %>% group_by(year, sitio, distancia.m, no.planta, flor) %>%
  summarise(pol.con.ratio=(0.0001+(0.9999-0.0001)*pol.con.ratio))

m19b <- glmmTMB(f7, data = pol.ld.m2, family = "beta_family")
m20b <- glmmTMB(f8, data = pol.ld.m2, family = "beta_family")

AIC(m19, m20, m19b, m20b)#m20
AIC(m19,m19b,m20,m20b)

simulationOutput <- simulateResiduals(fittedModel = m19b, plot = F, quantreg=T)
plot(simulationOutput)

summary(m20)

##Pollen tubes

#formulas
f9 <- tubes.c  ~ distancia.m * year + (1|sitio/no.planta)
f10 <- tubes.c  ~ distancia.m + year + (1|sitio/no.planta)

#GLMM
m21 <- glmmTMB(f9, data = pol.ld, family = "gaussian")
m22 <- glmmTMB(f10, data = pol.ld, family = "gaussian")

m23 <- glmmTMB(f9, data = pol.ld, family = "poisson")
m24 <- glmmTMB(f10, data = pol.ld, family = "poisson")

m25 <- glmmTMB(f9, data = pol.ld, family = "nbinom1")
m26 <- glmmTMB(f10, data = pol.ld, family = "nbinom1")

AIC(m21, m22, m23, m24, m25, m26) #25
AIC(m21,m23,m25,m22,m24,m26)

simulationOutput <- simulateResiduals(fittedModel = m26, plot = F)
plot(simulationOutput)

summary(m25)

##Pollen tubes ratio 

#formulas
f11 <- tubes.ratio  ~ distancia.m * year + (1|sitio/no.planta)
f12 <- tubes.ratio  ~ distancia.m + year + (1|sitio/no.planta)

#GLMM

m27 <-  glmmTMB(f11, data = pol.ld, family = "binomial")
m28 <-  glmmTMB(f12, data = pol.ld, family = "binomial")

#Beta distribution -> (0,1). So tubes.ratio -> (0.0001,0.9999)
pol.ld.m2 <- as.data.frame(pol.ld) %>% group_by(year, sitio, distancia.m, no.planta, flor) %>%
  summarise(tubes.ratio=(0.0001+(0.9999-0.0001)*tubes.ratio))

m27b <- glmmTMB(f11, data = pol.ld.m2, family = "beta_family")
m28b <- glmmTMB(f12, data = pol.ld.m2, family = "beta_family")

AIC(m27, m28, m27b, m28b)#m27
AIC(m27, m27b, m28, m28b)

simulationOutput <- simulateResiduals(fittedModel = m27, plot = F)
plot(simulationOutput)

summary(m27)

##fruit set
fruit.set.ld.m <- fruit.set.ld %>% mutate(fruit.set =ifelse(fruit.set > 1, 1, fruit.set))

#formulas
f14 <- fruit.set  ~ distancia.m * year + (1|sitio/planta)
f15 <- fruit.set~ distancia.m + year + (1|sitio/planta)

#GLMM
m29 <-glmmTMB(f14, data = fruit.set.ld.m, family = "binomial")
m30 <-glmmTMB(f15, data = fruit.set.ld.m, family = "binomial")

#Beta distribution -> (0,1). So fruit.set -> (0.0001,0.9999)
fruit.set.ld.m2 <- as.data.frame(fruit.set.ld.m) %>% group_by(year, sitio, distancia.m, planta) %>%
  summarise(fruit.set=(0.0001+(0.9999-0.0001)*fruit.set))

m29b <- glmmTMB(f14, data = fruit.set.ld.m2, family = "beta_family")
m30b <- glmmTMB(f15, data = fruit.set.ld.m2, family = "beta_family")

AIC(m29, m30, m29b, m30b)#m30
AIC(m29,m29b, m30,m30b)

simulationOutput <- simulateResiduals(fittedModel = m30, plot = F)
plot(simulationOutput)

summary(m30)

##seed set 

#formulas
f16 <- seed.set  ~ distancia.m * year + (1|sitio/planta)
f17 <- seed.set  ~ distancia.m + year + (1|sitio/planta)

#GLMM
m31 <- glmmTMB(f16, data = seed.set.ld, family="gaussian")
m32 <- glmmTMB(f17, data = seed.set.ld, family="gaussian")

m33 <- glmmTMB(f16, data = seed.set.ld, family="poisson")
m34 <- glmmTMB(f17, data = seed.set.ld, family="poisson")

m35 <- glmmTMB(f16, data = seed.set.ld, family="nbinom1")
m36 <- glmmTMB(f17, data = seed.set.ld, family="nbinom1")

AIC(m31, m32, m33, m34, m35, m36)#m35


simulationOutput <- simulateResiduals(fittedModel = m35, plot = F)
plot(simulationOutput)

summary(m35)


##viability
#formulas

f18 <- viabilidad ~ distancia.m * year + (1|sitio/planta)
f19 <- viabilidad ~ distancia.m + year + (1|sitio/planta)

#GLMM
m37 <- glmmTMB(f18, data = viab.ld, family = "binomial", na.action = na.omit)
m38 <- glmmTMB(f19, data = viab.ld, family = "binomial", na.action = na.omit)

#Beta distribution -> (0,1). So viabilidad -> (0.0001,0.9999)
viab.ld.m2 <- as.data.frame(viab.ld) %>% group_by(year, sitio, distancia.m, planta, fruto, semilla) %>%
  summarise(viabilidad=(0.0001+(0.9999-0.0001)*viabilidad))

m37b <- glmmTMB(f18, data = viab.ld.m2, family = "beta_family")
m38b <- glmmTMB(f19, data = viab.ld.m2, family = "beta_family")

AIC(m37, m38, m37b, m38b)#m38
AIC(m37,m37b,m38,m38b)

simulationOutput <- simulateResiduals(fittedModel = m38b, plot = F)
plot(simulationOutput)

summary(m38)

#weight
#formulas
f20 <- peso ~ distancia.m + (1 | sitio/planta)

#GLMM
m39 <- glmmTMB(f20, data = viab.ld, na.action = na.omit, family="gaussian")

simulationOutput <- simulateResiduals(fittedModel = m39, plot = F)
plot(simulationOutput)


summary(m39)


#table
table_ld <- tab_model(m6, m12,m18, m20, m25, m27, m30, m35, m38, m39,
                     show.ci=0.95,  show.r2  = F,
                     transform=NULL, show.aic =T, string.est="Estimates")
#CI for weight
confint(m39)


#correlation between pollen tubes and conspecific pollen grains
pol.ld.2018 <- pol.ld %>% filter(year=="2018")

shapiro.test(pol.ld.2018$pol.con) #not normal distribution
shapiro.test(pol.ld.2018$tubes.c) #not normal distribution
bartlett.test(list(pol.ld.2018$pol.con, pol.ld.2018$tubes.c)) #ok

#use spearman

cor.test(pol.ld.2018$pol.con, pol.ld.2018$tubes.c, method = "spearman")


####### Zuccagnia punctata

##Conspecific pollen grains#

#formulas
#idem f1 and f2 from larrea divaricata

#GLMM

m50 <- glmmTMB(f1, data = pol.zp, family = "gaussian")
m51<- glmmTMB(f2, data = pol.zp, family = "gaussian")

m52 <- glmmTMB(f1, data = pol.zp, family = "poisson")
m53 <- glmmTMB(f2, data = pol.zp, family = "poisson")

m54 <- glmmTMB(f1, data = pol.zp, family = "nbinom1")
m55 <- glmmTMB(f2, data = pol.zp, family = "nbinom1")


AIC(m50, m51, m52, m53, m54, m55) #m54
AIC(m50,m52,m54,m51,m53,m55)

simulationOutput <- simulateResiduals(fittedModel = m54, plot = F)
plot(simulationOutput)

summary(m54)


##Heteroespecific pollen grains

#formulas
#idem f3 and f4 from lar.div

#GLMM

m56 <- glmmTMB(f3, data = pol.zp, family = "gaussian")
m57 <- glmmTMB(f4, data = pol.zp, family = "gaussian")

m58 <- glmmTMB(f3, data = pol.zp, family = "poisson")
m59 <- glmmTMB(f4, data = pol.zp, family = "poisson")

m60 <- glmmTMB(f3, data = pol.zp, family = "nbinom1")
m61 <- glmmTMB(f4, data = pol.zp, family = "nbinom1")

AIC(m56, m57, m58, m59, m60, m61) #m61
AIC(m56,m58,m60,m57,m59,m61)

simulationOutput <- simulateResiduals(fittedModel = m61, plot = F)
plot(simulationOutput)

summary(m61)

##Total pollen grains

#formulas
#idem lar.div

#GLMM

m62 <- glmmTMB(f5, data = pol.zp, family = "gaussian")
m63 <- glmmTMB(f6, data = pol.zp, family = "gaussian")

m64 <- glmmTMB(f5, data = pol.zp, family = "poisson")
m65 <- glmmTMB(f6, data = pol.zp, family = "poisson")

m66 <- glmmTMB(f5, data = pol.zp, family = "nbinom1")
m67 <- glmmTMB(f6, data = pol.zp, family = "nbinom1")

AIC(m62, m63, m64, m65, m66, m67) #m67
AIC(m62,m64,m66,m63,m65,m67)

simulationOutput <- simulateResiduals(fittedModel = m67, plot = F)
plot(simulationOutput)

summary(m67)


##conspecific pollen grain ratio

#formulas
#idem lar.div

#GLMM
m68 <- glmmTMB(f7, data = pol.zp, family = "binomial")
m69 <- glmmTMB(f8, data = pol.zp, family = "binomial")

#Beta distribution -> (0,1). So pol.con.ratio -> (0.0001,0.9999)
pol.zp.m2 <- as.data.frame(pol.zp) %>% group_by(year, sitio, distancia.m, no.planta, flor) %>%
  summarise(pol.con.ratio=(0.0001+(0.9999-0.0001)*pol.con.ratio))

m68b <- glmmTMB(f7, data = pol.zp.m2, family = "beta_family")
m69b <- glmmTMB(f8, data = pol.zp.m2, family = "beta_family")

AIC(m68,m69, m68b, m69b)#m69
AIC(m68,m68b,m69,m69b)

simulationOutput <- simulateResiduals(fittedModel = m68, plot = F, quantreg=T)
plot(simulationOutput)

summary(m69)

##Pollen tubes

#formulas
#idem lar.div

#GLMM
m70 <- glmmTMB(f9, data = pol.zp, family = "gaussian")
m71 <- glmmTMB(f10, data = pol.zp, family = "gaussian")

m72 <- glmmTMB(f9, data = pol.zp, family = "poisson")
m73 <- glmmTMB(f10, data = pol.zp, family = "poisson")

m74 <- glmmTMB(f9, data = pol.zp, family = "nbinom1")
m75 <- glmmTMB(f10, data = pol.zp, family = "nbinom1")

AIC(m70, m71, m72, m73, m74, m75) #m74
AIC(m70,m72,m74,m71,m73,m75)

simulationOutput <- simulateResiduals(fittedModel = m74, plot = F)
plot(simulationOutput)

summary(m74)

##Pollen tubes ratio 

#formulas
#idem lar.div

#GLMM

m76 <-  glmmTMB(f11, data = pol.zp, family = "binomial")
m77 <-  glmmTMB(f12, data = pol.zp, family = "binomial")

#Beta distribution -> (0,1). So tubes.ratio -> (0.0001,0.9999)
pol.zp.m2 <- as.data.frame(pol.zp) %>% group_by(year, sitio, distancia.m, no.planta, flor) %>%
  summarise(tubes.ratio=(0.0001+(0.9999-0.0001)*tubes.ratio))

m76b <- glmmTMB(f11, data = pol.zp.m2, family = "beta_family")
m77b <- glmmTMB(f12, data = pol.zp.m2, family = "beta_family")

AIC(m76, m77, m76b, m77b)#m77
AIC(m76,m76b,m77,m77b)

simulationOutput <- simulateResiduals(fittedModel = m77, plot = F)
plot(simulationOutput)

summary(m77)

##fruit set
fruit.set.zp.m <- fruit.set.zp %>% mutate(fruit.set =ifelse(fruit.set > 1, 1, fruit.set))

#formulas
#idem lar.div

#GLMM
m78 <-glmmTMB(f14, data = fruit.set.zp.m, family = "binomial")
m79 <-glmmTMB(f15, data = fruit.set.zp.m, family = "binomial")

#Beta distribution -> (0,1). So fruit.set -> (0.0001,0.9999)
fruit.set.zp.m2 <- as.data.frame(fruit.set.zp.m) %>% group_by(year, sitio, distancia.m, planta) %>%
  summarise(fruit.set=(0.0001+(0.9999-0.0001)*fruit.set))

m78b <- glmmTMB(f14, data = fruit.set.zp.m2, family = "beta_family")
m79b <- glmmTMB(f15, data = fruit.set.zp.m2, family = "beta_family")

AIC(m78, m79, m78b, m79b)#m79
AIC(m78,m78b,m79,m79b)

simulationOutput <- simulateResiduals(fittedModel = m79, plot = F)
plot(simulationOutput)

summary(m79)

##seed set 

#formulas
#idem lar.div

#GLMM
m80 <- glmmTMB(f16, data = seed.set.zp, family="gaussian")
m81 <- glmmTMB(f17, data = seed.set.zp, family="gaussian")

m82 <- glmmTMB(f16, data = seed.set.zp, family="poisson")
m83 <- glmmTMB(f17, data = seed.set.zp, family="poisson")

m84 <- glmmTMB(f16, data = seed.set.zp, family="nbinom1")
m85 <- glmmTMB(f17, data = seed.set.zp, family="nbinom2")

AIC(m80, m81, m82, m83, m84, m85)#m80
AIC(m80,m82,m84,m81,m83,m85)

simulationOutput <- simulateResiduals(fittedModel = m80, plot = F)
plot(simulationOutput)

summary(m80)


##viability
#formulas
#idem lar.div

#GLMM
m86 <- glmmTMB(f18, data = viab.zp, family = "binomial", na.action = na.omit)
m87 <- glmmTMB(f19, data = viab.zp, family = "binomial", na.action = na.omit)

#Beta distribution -> (0,1). So viabilidad -> (0.0001,0.9999)
viab.zp.m2 <- as.data.frame(viab.zp) %>% group_by(year, sitio, distancia.m, planta, fruto, semilla) %>%
  summarise(viabilidad=(0.0001+(0.9999-0.0001)*viabilidad))

m86b <- glmmTMB(f18, data = viab.zp.m2, family = "beta_family")
m87b <- glmmTMB(f19, data = viab.zp.m2, family = "beta_family")

AIC(m86, m87, m86b, m87b)#m86
AIC(m86,m86b,m87,m87b)

simulationOutput <- simulateResiduals(fittedModel = m86, plot = F)
plot(simulationOutput)

summary(m86)

#weight
#formulas
#idem lar.div

#GLMM
m88 <- glmmTMB(f20, data = viab.zp, na.action = na.omit, family="gaussian")

simulationOutput <- simulateResiduals(fittedModel = m88, plot = F)
plot(simulationOutput)

summary(m88)

#table
table_zp <- tab_model(m54,m61,m66,m69,m74,m77,m79,m80,m86,m88,
                     show.ci=0.95, show.r2  = F,
                     transform=NULL, show.aic =T, string.est="Estimates")
#CI for weight
confint(m88)

####### Larrea cuneifolia

##Conspecific pollen grains#

#formulas
fa <- pol.con ~ distancia.m + (1|sitio/no.planta)

#GLMM

m91 <- glmmTMB(fa, data = pol.lc, family = "poisson")

simulationOutput <- simulateResiduals(fittedModel = m91, plot = F)
plot(simulationOutput)
#dispersion

m92 <- glmmTMB(fa, data = pol.lc, family = "nbinom1")

simulationOutput <- simulateResiduals(fittedModel = m92, plot = F)
plot(simulationOutput)

summary(m92)


##Heteroespecific pollen grains

#formulas
fb <- pol.het ~ distancia.m + (1|sitio/no.planta)

#GLMM

m94 <- glmmTMB(fb, data = pol.lc, family = "poisson")

simulationOutput <- simulateResiduals(fittedModel = m94, plot = F)
plot(simulationOutput)
#dispersion

m95 <- glmmTMB(fb, data = pol.lc, family = "nbinom1")

simulationOutput <- simulateResiduals(fittedModel = m95, plot = F)
plot(simulationOutput)


summary(m95)

##Total pollen grains

#formulas
fc <- pol.tot ~ distancia.m + (1|sitio/no.planta)

#GLMM

m97 <- glmmTMB(fc, data = pol.lc, family = "poisson")

simulationOutput <- simulateResiduals(fittedModel = m97, plot = F)
plot(simulationOutput)
#dispersion

m98 <- glmmTMB(fc, data = pol.lc, family = "nbinom1")

simulationOutput <- simulateResiduals(fittedModel = m98, plot = F)
plot(simulationOutput)

summary(m98)


##conspecific pollen grain ratio

#formulas
fe <- pol.con.ratio ~ distancia.m + (1|sitio)

#GLMM
m100 <- glmmTMB(fe, data = pol.lc, family = "binomial")

simulationOutput <- simulateResiduals(fittedModel = m100, plot = F, quantreg=T)
plot(simulationOutput)

summary(m100)


##Pollen tubes

#formulas
ff <- tubes.c ~ distancia.m + (1|sitio/no.planta)

#GLMM
m102 <- glmmTMB(ff, data = pol.lc, family = "poisson")

simulationOutput <- simulateResiduals(fittedModel = m102, plot = F)
plot(simulationOutput)

m103 <- glmmTMB(ff, data = pol.lc, family = "nbinom1")

simulationOutput <- simulateResiduals(fittedModel = m103, plot = F)
plot(simulationOutput)

summary(m103)

##Pollen tubes ratio 

#formulas
fg <- tubes.ratio ~ distancia.m + (1|sitio/no.planta)

#GLMM

m104 <-  glmmTMB(fg, data = pol.lc, family = "binomial")

simulationOutput <- simulateResiduals(fittedModel = m104, plot = F)
plot(simulationOutput)

summary(m104)

##fruit set
fruit.set.lc.m <- fruit.set.lc %>% mutate(fruit.set =ifelse(fruit.set > 1, 1, fruit.set))

#formulas
fh <- fruit.set  ~ distancia.m + (1|sitio/planta)

#GLMM
m105 <-glmmTMB(fh, data = fruit.set.lc.m, family = "binomial")

simulationOutput <- simulateResiduals(fittedModel = m105, plot = F)
plot(simulationOutput)

summary(m105)

##seed set 

#formulas
fi <- seed.set  ~ distancia.m + (1|sitio/planta)

#GLMM
m107 <- glmmTMB(fi, data = seed.set.lc, family="poisson")

simulationOutput <- simulateResiduals(fittedModel = m107, plot = F)
plot(simulationOutput)

summary(m107)


##viability
#formulas
fj <- viabilidad  ~ distancia.m + (1|sitio/planta)

#GLMM
m109 <- glmmTMB(fj, data = viab.lc, family = "binomial", na.action = na.omit)

simulationOutput <- simulateResiduals(fittedModel = m109, plot = F)
plot(simulationOutput)

summary(m109)

#weight
#formulas
fk <- peso  ~ distancia.m + (1|sitio/planta)

#GLMM
m110 <- glmmTMB(fk, data = viab.lc, na.action = na.omit, family="gaussian")

simulationOutput <- simulateResiduals(fittedModel = m110, plot = F)
plot(simulationOutput)

summary(m110)

#table
table_lc <- tab_model(m92,m95,m98,m100,m103,m104,m105,m107,m109,m110,
                     show.ci=0.95, show.r2  = F,
                     transform=NULL, show.aic =T, string.est="Estimates")
#CI for weight
confint(m110)


##PLOTS
## larrea divricata
#Plots
#conespecific pollen grains
pol.con.ld.p.all <- ggpredict(m6, terms = c("distancia.m", "year"), type = "simulate")
pol.con.ld.p.all <-pol.con.ld.p.all %>% rename(distancia.m=x, year=group)

#heteroespecific pollen grains
pol.het.ld.p.all <- ggpredict(m12, terms = c("distancia.m", "year"))
pol.het.ld.p.all <-pol.het.ld.p.all %>% rename(distancia.m=x, year=group)

#total pollen grains
pol.tot.ld.p.all <- ggpredict(m18, terms = c("distancia.m","year"), type="simulate")
pol.tot.ld.p.all <- pol.tot.ld.p.all %>%  rename(distancia.m=x, year=group)

#Conspecific pollen grain ratio
pol.con.ratio.ld.p.all <- ggpredict(m20, terms = c("distancia.m", "year"))
pol.con.ratio.ld.p.all <- pol.con.ratio.ld.p.all %>% rename(distancia.m=x, year=group)

#pollen tubes
pol.tubes.ld.p.all <- ggpredict(m25, terms = c("distancia.m", "year"), type="simulate")
pol.tubes.ld.p.all <- pol.tubes.ld.p.all %>% rename(distancia.m=x, year=group)

#Pollen tube ratio
pol.tubes.ratio.ld.p.all <- ggpredict(m27, terms = c("distancia.m","year"))
pol.tubes.ratio.ld.p.all <- pol.tubes.ratio.ld.p.all %>% rename(distancia.m=x, year=group)

#Fruit set
fruit.set.ld.p.all <- ggpredict(m30, terms = c("distancia.m", "year"))
fruit.set.ld.p.all <- fruit.set.ld.p.all %>% rename(distancia.m=x, year=group)

#Seed set 
seed.set.ld.p.all <- ggpredict(m35, terms = c("distancia.m","year"))
seed.set.ld.p.all <- seed.set.ld.p.all %>% rename(distancia.m=x, year=group)

#Seed viability
seed.viab.ld.p.all <- ggpredict(m38, terms = c("distancia.m", "year"))
seed.viab.ld.p.all <- seed.viab.ld.p.all %>% rename(distancia.m=x, year=group)

#Weight
seed.weight.ld.p <- ggpredict(m39, terms = c("distancia.m"))
seed.weight.ld.p <- seed.weight.ld.p %>% rename(distancia.m=x, year=group)


#plot

ld_pol_con_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$pol.con)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$pol.con),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Conespecific pollen grains") +
  theme_classic()



ld_pol_het_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$pol.het)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$pol.het),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.het.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Heteroespecific pollen grains") +
  theme_classic()


ld_pol_tot_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$pol.tot)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$pol.tot),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tot.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
    labs(title = " ", x=" ", y="Total pollen grains") +
  theme_classic()


ld_pol_con_ratio_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$pol.con.ratio)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$pol.con.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.ratio.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Conspecific pollen grain ratio") +
  theme_classic()


ld_pol_tubes_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$tubes.c)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$tubes.c),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Pollen tubes") +
  theme_classic()


ld_pol_tube_ratio_all <- ggplot(data=NULL, aes(x=pol.ld$distancia.m, y=pol.ld$tubes.ratio)) +
  #geom_point(aes(x = pol.ld$distancia.m, y = pol.ld$tubes.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.ratio.ld.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year),position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Pollen tube ratio") +
  theme_classic()


ld_fruit_set_all <- ggplot(data=NULL, aes(x=fruit.set.ld.m$distancia.m, y=fruit.set.ld.m$fruit.set)) +
  #geom_point(aes(x = fruit.set.ld.m$distancia.m, y = fruit.set.ld.m$fruit.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=fruit.set.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Fruit set") +
  theme_classic()


ld_seed_set_all <- ggplot(data=NULL, aes(x=seed.set.ld$distancia.m, y=seed.set.ld$seed.set)) +
  #geom_point(aes(x = seed.set.ld$distancia.m, y = seed.set.ld$seed.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.set.ld.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high,group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Seed set") +
  theme_classic()


ld_seed_viab_all <- ggplot(data=NULL, aes(x=vaib.ld$distancia.m, y=viab.ld$vaibilidad)) +
  #geom_point(aes(x = viab.ld$distancia.m, y = viab.ld$viabilidad),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.viab.ld.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#6B990F", "#990F0F", "#260F99")) +
  labs(title = " ", x="Distance (m) ", y="Seed viability") +
  theme_classic()


ld_seed_weight_all <- ggplot(data=NULL, aes(x=viab.ld$distancia.m, y=viab.ld$peso)) +
  #geom_point(aes(x = viab.ld$distancia.m, y = viab.ld$peso),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.weight.ld.p,aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, colour=year),size=0.3) +
  #scale_y_continuous(limits = c(0.001, 0.004)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x="Distance (m)", y="Seed weight") +
  theme_classic()




ld <- ggarrange(ld_pol_con_all, ld_pol_het_all, ld_pol_tot_all, ld_pol_con_ratio_all, ld_pol_tubes_all,
                ld_pol_tube_ratio_all, ld_fruit_set_all, ld_seed_set_all, ld_seed_viab_all, 
                ld_seed_weight_all, labels = c("A", "B", "C", "D", "E", "F", "G", "H", "I", "J"),
                common.legend = TRUE, legend = "right")
annotate_figure(ld,
                top = text_grob("Larrea divaricata", color = "black", face = "italic", size = 15))



## Zuccagnia punctata
#Plots
#conespecific pollen grains
pol.con.zp.p.all <- ggpredict(m54, terms = c("distancia.m", "year"))
pol.con.zp.p.all <-pol.con.zp.p.all %>% rename(distancia.m=x, year=group)

#heteroespecific pollen grains
pol.het.zp.p.all <- ggpredict(m61, terms = c("distancia.m"))
pol.het.zp.p.all <-pol.het.zp.p.all %>% rename(distancia.m=x, year=group)

#total pollen grains
pol.tot.zp.p.all <- ggpredict(m66, terms = c("distancia.m", "year"))
pol.tot.zp.p.all <- pol.tot.zp.p.all %>%  rename(distancia.m=x, year=group)

#Conspecific pollen grain ratio
pol.con.ratio.zp.p.all <- ggpredict(m69, terms = c("distancia.m", "year"))
pol.con.ratio.zp.p.all <- pol.con.ratio.zp.p.all %>% rename(distancia.m=x, year=group)

#pollen tubes
pol.tubes.zp.p.all <- ggpredict(m74, terms = c("distancia.m", "year"))
pol.tubes.zp.p.all <- pol.tubes.zp.p.all %>% rename(distancia.m=x, year=group)

#Pollen tube ratio
pol.tubes.ratio.zp.p.all <- ggpredict(m77, terms = c("distancia.m", "year"))
pol.tubes.ratio.zp.p.all <- pol.tubes.ratio.zp.p.all %>% rename(distancia.m=x, year=group)

#Fruit set
fruit.set.zp.p.all <- ggpredict(m79, terms = c("distancia.m", "year"))
fruit.set.zp.p.all <- fruit.set.zp.p.all %>% rename(distancia.m=x, year=group)

#Seed set 
seed.set.zp.p.all <- ggpredict(m80, terms = c("distancia.m", "year"))
seed.set.zp.p.all <- seed.set.zp.p.all %>% rename(distancia.m=x, year=group)

#Seed viability
seed.viab.zp.p.all <- ggpredict(m86, terms = c("distancia.m", "year"))
seed.viab.zp.p.all <- seed.viab.zp.p.all %>% rename(distancia.m=x, year=group)

#Weight
seed.weight.zp.p <- ggpredict(m88, terms = c("distancia.m"))
seed.weight.zp.p <- seed.weight.zp.p %>% rename(distancia.m=x, year=group)


#plot

zp_pol_con_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$pol.con)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$pol.con),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  #scale_y_continuous(limits = c(0, 50)) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Conespecific pollen grains") +
  theme_classic()

zp_pol_het_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$pol.het)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$pol.het),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.het.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high), size=0.3) +
  #scale_y_continuous(limits = c(0, 75)) +
  #scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Heteroespecific pollen grains") +
  theme_classic()


zp_pol_tot_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$pol.tot)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$pol.tot),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tot.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  #scale_y_continuous(limits = c(0, 100)) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Total pollen grains") +
  theme_classic()


zp_pol_con_ratio_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$pol.con.ratio)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$pol.con.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.ratio.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Conspecific pollen grain ratio") +
  theme_classic()


zp_pol_tubes_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$tubes.c)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$tubes.c),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  #scale_y_continuous(limits = c(0, 25)) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Pollen tubes") +
  theme_classic()


zp_pol_tube_ratio_all <- ggplot(data=NULL, aes(x=pol.zp$distancia.m, y=pol.zp$tubes.ratio)) +
  #geom_point(aes(x = pol.zp$distancia.m, y = pol.zp$tubes.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.ratio.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Pollen tube ratio") +
  theme_classic()

zp_fruit_set_all <- ggplot(data=NULL, aes(x=fruit.set.zp.m$distancia.m, y=fruit.set.zp.m$fruit.set)) +
  #geom_point(aes(x = fruit.set.zp.m$distancia.m, y = fruit.set.zp.m$fruit.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=fruit.set.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  #scale_y_continuous(limits = c(0, 0.5)) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Fruit set") +
  theme_classic()


zp_seed_set_all <- ggplot(data=NULL, aes(x=seed.set.zp$distancia.m, y=seed.set.zp$seed.set)) +
  #geom_point(aes(x = seed.set.zp$distancia.m, y = seed.set.zp$seed.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.set.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x=" ", y="Seed set") +
  theme_classic()


zp_seed_viab_all <- ggplot(data=NULL, aes(x=vaib.zp$distancia.m, y=viab.zp$vaibilidad)) +
  #geom_point(aes(x = viab.zp$distancia.m, y = viab.zp$viabilidad),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.viab.zp.p.all, aes(x =as.factor(distancia.m), y=predicted, ymin = conf.low, ymax = conf.high, group=year, colour=year), position=position_dodge(0.7), size=0.3) +
  scale_colour_manual(name= "Year", values=c("#990F0F", "#260F99")) +
  labs(title = " ", x="Distance (m) ", y="Seed viability") +
  theme_classic()


zp_seed_weight_all <- ggplot(data=NULL, aes(x=viab.zp$distancia.m, y=viab.zp$peso)) +
  #geom_point(aes(x = viab.zp$distancia.m, y = viab.zp$peso),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.weight.zp.p, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, colour=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x="Distance (m) ", y="Seed weight") +
  theme_classic()




zp <- ggarrange(zp_pol_con_all, zp_pol_het_all, zp_pol_tot_all, zp_pol_con_ratio_all, zp_pol_tubes_all,
                zp_pol_tube_ratio_all, zp_fruit_set_all, zp_seed_set_all, zp_seed_viab_all, 
                zp_seed_weight_all, labels = c("A", "B", "C", "D", "E", "F", "G", "H", "I", "J"),
                common.legend = TRUE, legend = "right")
annotate_figure(zp,
                top = text_grob("Zuccagnia punctata", color = "black", face = "italic", size = 15))



## Larrea cuneifolia
#Plots
#conespecific pollen grains
pol.con.lc.p.all <- ggpredict(m92, terms = c("distancia.m"))
pol.con.lc.p.all <-pol.con.lc.p.all %>% rename(distancia.m=x, year=group)

#heteroespecific pollen grains

pol.het.lc.p.all <- ggpredict(m95, terms = c("distancia.m"))
pol.het.lc.p.all <-pol.het.lc.p.all %>% rename(distancia.m=x, year=group)

#total pollen grains

pol.tot.lc.p.all <- ggpredict(m98, terms = c("distancia.m"))
pol.tot.lc.p.all <- pol.tot.lc.p.all %>%  rename(distancia.m=x, year=group)

#Conspecific pollen grain ratio

pol.con.ratio.lc.p.all <- ggpredict(m100, terms = c("distancia.m"))
pol.con.ratio.lc.p.all <- pol.con.ratio.lc.p.all %>% rename(distancia.m=x, year=group)

#pollen tubes

pol.tubes.lc.p.all <- ggpredict(m103, terms = c("distancia.m"))
pol.tubes.lc.p.all <- pol.tubes.lc.p.all %>% rename(distancia.m=x, year=group)

#Pollen tube ratio

pol.tubes.ratio.lc.p.all <- ggpredict(m104, terms = c("distancia.m"))
pol.tubes.ratio.lc.p.all <- pol.tubes.ratio.lc.p.all %>% rename(distancia.m=x, year=group)

#Fruit set

fruit.set.lc.p.all <- ggpredict(m105, terms = c("distancia.m"))
fruit.set.lc.p.all <- fruit.set.lc.p.all %>% rename(distancia.m=x, year=group)

#Seed set 

seed.set.lc.p.all <- ggpredict(m107, terms = c("distancia.m"))
seed.set.lc.p.all <- seed.set.lc.p.all %>% rename(distancia.m=x, year=group)

#Seed viability
seed.viab.lc.p.all <- ggpredict(m109, terms = c("distancia.m"))
seed.viab.lc.p.all <- seed.viab.lc.p.all %>% rename(distancia.m=x, year=group)

#Weight
seed.weight.lc.p <- ggpredict(m110, terms = c("distancia.m"))
seed.weight.lc.p <- seed.weight.lc.p %>% rename(distancia.m=x, year=group)


#plot

lc_pol_con_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$pol.con)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$pol.con),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  #scale_y_continuous(limits = c(0, 140)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Conespecific pollen grains") +
  theme_classic()

lc_pol_het_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$pol.het)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$pol.het),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.het.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  #scale_y_continuous(limits = c(0, 40)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Heteroespecific pollen grains") +
  theme_classic()


lc_pol_tot_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$pol.tot)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$pol.tot),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tot.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  #scale_y_continuous(limits = c(0, 160)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Total pollen grains") +
  theme_classic()


lc_pol_con_ratio_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$pol.con.ratio)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$pol.con.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.con.ratio.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  #scale_y_continuous(limits = c(0.25, 1)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Conspecific pollen grain ratio") +
  theme_classic()


lc_pol_tubes_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$tubes.c)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$tubes.c),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  #scale_y_continuous(limits = c(0, 100)) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Pollen tubes") +
  theme_classic()


lc_pol_tube_ratio_all <- ggplot(data=NULL, aes(x=pol.lc$distancia.m, y=pol.lc$tubes.ratio)) +
  #geom_point(aes(x = pol.lc$distancia.m, y = pol.lc$tubes.ratio),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=pol.tubes.ratio.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Pollen tube ratio") +
  theme_classic()


lc_fruit_set_all <- ggplot(data=NULL, aes(x=fruit.set.lc.m$distancia.m, y=fruit.set.lc.m$fruit.set)) +
  #geom_point(aes(x = fruit.set.lc.m$distancia.m, y = fruit.set.lc.m$fruit.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=fruit.set.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Fruit set") +
  theme_classic()


lc_seed_set_all <- ggplot(data=NULL, aes(x=seed.set.lc$distancia.m, y=seed.set.lc$seed.set)) +
  #geom_point(aes(x = seed.set.lc$distancia.m, y = seed.set.lc$seed.set),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.set.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x=" ", y="Seed set") +
  theme_classic()


lc_seed_viab_all <- ggplot(data=NULL, aes(x=vaib.lc$distancia.m, y=viab.lc$vaibilidad)) +
  #geom_point(aes(x = viab.lc$distancia.m, y = viab.lc$viabilidad),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.viab.lc.p.all, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x="Distance (m)", y="Seed viability") +
  theme_classic()


lc_seed_weight_all <- ggplot(data=NULL, aes(x=viab.lc$distancia.m, y=viab.lc$peso)) +
  #geom_point(aes(x = viab.lc$distancia.m, y = viab.lc$peso),colour="#009ACD", alpha=0.5, position=position_jitter(0.2)) +
  geom_pointrange(data=seed.weight.lc.p, aes(x =distancia.m, y=predicted, ymin = conf.low, ymax = conf.high, color=year),size=0.3) +
  scale_colour_manual(name= "Year", values="#260F99") +
  labs(title = " ", x="Distance (m) ", y="Seed weight") +
  theme_classic()




lc <- ggarrange(lc_pol_con_all, lc_pol_het_all, lc_pol_tot_all, lc_pol_con_ratio_all, lc_pol_tubes_all,
                lc_pol_tube_ratio_all, lc_fruit_set_all, lc_seed_set_all, lc_seed_viab_all, 
                lc_seed_weight_all, labels = c("A", "B", "C", "D", "E", "F", "G", "H", "I", "J"),
                common.legend = TRUE, legend = "right")
annotate_figure(lc,
                top = text_grob("Larrea cuneifolia", color = "black", face = "italic", size = 15))



